CustomResourceEvent

Enum CustomResourceEvent 

pub enum CustomResourceEvent<T> {
    Create(CloudformationPayload<T>),
    Update(CloudformationPayload<T>),
    Delete(CloudformationPayload<T>),
}
Defines an event payload that is sent to a lambda function by AWS Cloud Formation. This payload is defined by AWS as the following:

{
  "RequestType" : "Delete",
  "RequestId" : "unique id for this delete request",
  "ResponseURL" : "pre-signed-url-for-delete-response",
  "ResourceType" : "Custom::MyCustomResourceType",
  "LogicalResourceId" : "name of resource in template",
  "StackId" : "arn:aws:cloudformation:us-east-2:namespace:stack/stack-name/guid",
  "PhysicalResourceId" : "custom resource provider-defined physical id",
  "ResourceProperties" : {
     "key1" : "string",
     "key2" : [ "list" ],
     "key3" : { "key4" : "map" }
  }
}

The entire payload is the same for each custom resource except for the ResourceProperties section, so that is available as a generic type for which we are able to create the schema for the resource properties on your own.

Variants



Create(CloudformationPayload<T>)

Defines a cloudformation payload that happens on a create of the resource.



Update(CloudformationPayload<T>)

Defines a cloudforamtion payload that happens on ab update to the resource.



Delete(CloudformationPayload<T>)

Defines a cloudforamtion payload that happens on the deletion the resource.