CustomResourceResponse

Struct CustomResourceResponse 

pub struct CustomResourceResponse { /* private fields */ }
Define a response payload for the execution of a cloud formation custom resource data that is sent back to cloud formation after the process of executing the custom resource is complete.

Implementations

Source

impl CustomResourceResponse

pub fn set_no_echo(self, value: bool) -> Self

Indicates whether to mask the output of the custom resource when retrieved by using the Fn::GetAtt function. If set to true, all returned values are masked with asterisks (*****), except for those stored in the Metadata section of the template. Cloud Formation does not transform, modify, or redact any information you include in the Metadata section. The default value is false.

pub fn add_data(self, key: &str, value: &str) -> Self

Writes a new key value pair to the data section of the response.

The custom resource provider-defined name-value pairs to send with the response. You can access the values provided here by name in the template with Fn::GetAtt.

pub async fn finish(self) -> Result<(), Error>

Sends the response object (self) to the response url of the custom resource.

This finishes the cloudformation object change (create/update/delete).

Errors

When the request fails to execute the request