pub struct CustomResourceResponse { /* private fields */ }Expand description
Define a response payload for the execution of a cloud formation custom resource data that is sent back to cloud formation after the process of executing the custom resource is complete.
Implementations
Sourceimpl CustomResourceResponse
impl CustomResourceResponse
Sourcepub fn set_no_echo(self, value: bool) -> Self
pub fn set_no_echo(self, value: bool) -> Self
Indicates whether to mask the output of the custom resource when retrieved by using the Fn::GetAtt function.
If set to true, all returned values are masked with asterisks (*****), except for those stored in the Metadata
section of the template. Cloud Formation does not transform, modify, or redact any information you include in
the Metadata section. The default value is false.